'''
Created by auto_sdk on 2019.03.11
'''
from dingtalk.api.base import RestApi
class OapiChatUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.add_extidlist = None
		self.add_useridlist = None
		self.chatBannedType = None
		self.chatid = None
		self.del_extidlist = None
		self.del_useridlist = None
		self.icon = None
		self.isBan = None
		self.managementType = None
		self.mentionAllAuthority = None
		self.name = None
		self.owner = None
		self.ownerType = None
		self.searchable = None
		self.showHistoryType = None
		self.validationType = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.chat.update'



'''
Created by auto_sdk on 2021.04.21
'''
from dingtalk.api.base import RestApi
class OapiEduRecommendReturnRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.class_id = None
		self.labelList = None
		self.learnTime = None
		self.out_content_id = None
		self.out_tx_id = None
		self.result_type = None
		self.result_value = None
		self.return_url = None
		self.subject_code = None
		self.summary = None
		self.textbook_code = None
		self.thumbnail = None
		self.title = None
		self.totalTime = None
		self.type = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.recommend.return'



'''
Created by auto_sdk on 2022.04.25
'''
from dingtalk.api.base import RestApi
class OapiCspaceAuditlogListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.end_date = None
		self.load_more_biz_id = None
		self.load_more_gmt_create = None
		self.page_size = None
		self.start_date = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.cspace.auditlog.list'



'''
Created by auto_sdk on 2018.07.25
'''
from dingtalk.api.base import RestApi
class OapiUserListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.department_id = None
		self.lang = None
		self.offset = None
		self.order = None
		self.size = None

	def getHttpMethod(self):
		return 'GET'

	def getapiname(self):
		return 'dingtalk.oapi.user.list'



'''
Created by auto_sdk on 2020.02.26
'''
from dingtalk.api.base import RestApi
class OapiSmartdeviceQrQueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.qr_content = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartdevice.qr.query'
